==> haskell-errors-2.3.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.3.0
id: errors-2.3.0-FkWtMDbTCAG9tQYZlLuJEI
key: errors-2.3.0-FkWtMDbTCAG9tQYZlLuJEI
license: BSD-3-Clause
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
abi: ab011b81b57f60d804e3d3f02d2ca783
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
import-dirs: /usr/lib/ghc-8.4.3/site-local/errors-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/errors-2.3.0
hs-libraries: HSerrors-2.3.0-FkWtMDbTCAG9tQYZlLuJEI
depends:
    base-4.11.1.0 exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 text-1.2.3.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.3.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.3.0
id: errors-2.3.0-7FfgxG1XlR88tNvX9ISace
key: errors-2.3.0-7FfgxG1XlR88tNvX9ISace
license: BSD-3-Clause
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
abi: 90e72a9104b2251eefbbdc1f55c77a7f
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
import-dirs: /usr/lib/ghc-8.6.1/site-local/errors-2.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/errors-2.3.0
hs-libraries: HSerrors-2.3.0-7FfgxG1XlR88tNvX9ISace
depends:
    base-4.12.0.0 exceptions-0.10.0-4DJq1L1pYJ32FjrP4E9tSI
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
